@@ -68,6 +68,7 @@ struct _ESourceWebdavPrivate {
 	gboolean avoid_ifmatch;
 	gboolean calendar_auto_schedule;
 	SoupURI *soup_uri;
+	guint order;
 };
 
 enum {
@@ -80,7 +81,8 @@ enum {
 	PROP_RESOURCE_PATH,
 	PROP_RESOURCE_QUERY,
 	PROP_SOUP_URI,
-	PROP_SSL_TRUST
+	PROP_SSL_TRUST,
+	PROP_ORDER
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (
@@ -322,6 +324,12 @@ source_webdav_set_property (GObject *object,
 				E_SOURCE_WEBDAV (object),
 				g_value_get_string (value));
 			return;
+
+		case PROP_ORDER:
+			e_source_webdav_set_order (
+				E_SOURCE_WEBDAV (object),
+				g_value_get_uint (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -396,6 +404,13 @@ source_webdav_get_property (GObject *object,
 				e_source_webdav_dup_ssl_trust (
 				E_SOURCE_WEBDAV (object)));
 			return;
+
+		case PROP_ORDER:
+			g_value_set_uint (
+				value,
+				e_source_webdav_get_order (
+				E_SOURCE_WEBDAV (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -621,6 +636,20 @@ e_source_webdav_class_init (ESourceWebdavClass *class)
 			G_PARAM_EXPLICIT_NOTIFY |
 			G_PARAM_STATIC_STRINGS |
 			E_SOURCE_PARAM_SETTING));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_ORDER,
+		g_param_spec_uint (
+			"order",
+			"Order",
+			"A sorting order of the resource",
+			0, G_MAXUINT, (guint) -1,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_EXPLICIT_NOTIFY |
+			G_PARAM_STATIC_STRINGS |
+			E_SOURCE_PARAM_SETTING));
 }
 
 static void
@@ -1586,3 +1615,43 @@ e_source_webdav_set_ssl_trust_response (ESourceWebdav *extension,
 	g_free (host);
 	g_free (hash);
 }
+
+/**
+ * e_source_webdav_get_order:
+ * @extension: an #ESourceWebdav
+ *
+ * Returns: the sorting order of the resource, if known. The default
+ *    is (guint) -1, which means unknown/unset.
+ *
+ * Since: 3.40
+ **/
+guint
+e_source_webdav_get_order (ESourceWebdav *extension)
+{
+	g_return_val_if_fail (E_IS_SOURCE_WEBDAV (extension), (guint) -1);
+
+	return extension->priv->order;
+}
+
+/**
+ * e_source_webdav_set_order:
+ * @extension: an #ESourceWebdav
+ * @order: a sorting order
+ *
+ * Set the sorting order of the resource.
+ *
+ * Since: 3.40
+ **/
+void
+e_source_webdav_set_order (ESourceWebdav *extension,
+			   guint order)
+{
+	g_return_if_fail (E_IS_SOURCE_WEBDAV (extension));
+
+	if (extension->priv->order == order)
+		return;
+
+	extension->priv->order = order;
+
+	g_object_notify (G_OBJECT (extension), "order");
+}
