@@ -91,6 +91,7 @@ e_webdav_discover_split_resources (WebDAVDiscoverData *wdd,
 			discovered->display_name = g_strdup (resource->display_name);
 			discovered->description = g_strdup (resource->description);
 			discovered->color = g_strdup (resource->color);
+			discovered->order = resource->order;
 
 			if (resource->kind == E_WEBDAV_RESOURCE_KIND_ADDRESSBOOK) {
 				wdd->addressbooks = g_slist_prepend (wdd->addressbooks, discovered);
@@ -146,8 +147,7 @@ e_webdav_discover_traverse_propfind_response_cb (EWebDAVSession *webdav,
 
 			if (full_href && *full_href && GPOINTER_TO_INT (g_hash_table_contains (wdd->covered_hrefs, full_href)) != 2 &&
 			    e_webdav_session_list_sync (webdav, full_href, E_WEBDAV_DEPTH_THIS_AND_CHILDREN,
-				E_WEBDAV_LIST_SUPPORTS | E_WEBDAV_LIST_DISPLAY_NAME | E_WEBDAV_LIST_DESCRIPTION |
-				E_WEBDAV_LIST_COLOR | E_WEBDAV_LIST_ONLY_ADDRESSBOOK | E_WEBDAV_LIST_ALL,
+				E_WEBDAV_LIST_ONLY_ADDRESSBOOK | E_WEBDAV_LIST_ALL,
 				&resources, wdd->cancellable, &local_error)) {
 				e_webdav_discover_split_resources (wdd, resources);
 				g_slist_free_full (resources, e_webdav_resource_free);
@@ -183,8 +183,7 @@ e_webdav_discover_traverse_propfind_response_cb (EWebDAVSession *webdav,
 
 			if (full_href && *full_href && GPOINTER_TO_INT (g_hash_table_contains (wdd->covered_hrefs, full_href)) != 2 &&
 			    e_webdav_session_list_sync (webdav, full_href, E_WEBDAV_DEPTH_THIS_AND_CHILDREN,
-				E_WEBDAV_LIST_SUPPORTS | E_WEBDAV_LIST_DISPLAY_NAME | E_WEBDAV_LIST_DESCRIPTION |
-				E_WEBDAV_LIST_COLOR | E_WEBDAV_LIST_ONLY_CALENDAR | E_WEBDAV_LIST_ALL,
+				E_WEBDAV_LIST_ONLY_CALENDAR | E_WEBDAV_LIST_ALL,
 				&resources, wdd->cancellable, &local_error)) {
 				e_webdav_discover_split_resources (wdd, resources);
 				g_slist_free_full (resources, e_webdav_resource_free);
@@ -269,7 +268,6 @@ e_webdav_discover_traverse_propfind_response_cb (EWebDAVSession *webdav,
 		if (GPOINTER_TO_INT (g_hash_table_contains (wdd->covered_hrefs, href)) != 2 &&
 		    !g_cancellable_is_cancelled (wdd->cancellable) &&
 		    e_webdav_session_list_sync (webdav, href, E_WEBDAV_DEPTH_THIS,
-			E_WEBDAV_LIST_SUPPORTS | E_WEBDAV_LIST_DISPLAY_NAME | E_WEBDAV_LIST_DESCRIPTION | E_WEBDAV_LIST_COLOR |
 			(is_calendar ? E_WEBDAV_LIST_ONLY_CALENDAR : 0) | (is_addressbook ? E_WEBDAV_LIST_ONLY_ADDRESSBOOK : 0) | E_WEBDAV_LIST_ALL,
 			&resources, wdd->cancellable, &local_error)) {
 			e_webdav_discover_split_resources (wdd, resources);
@@ -295,7 +293,7 @@ e_webdav_discover_traverse_propfind_response_cb (EWebDAVSession *webdav,
 			e_webdav_resource_new (E_WEBDAV_RESOURCE_KIND_WEBDAV_NOTES,
 				E_WEBDAV_RESOURCE_SUPPORTS_WEBDAV_NOTES, href, NULL,
 				_("Notes"),
-				NULL, 0, 0, 0, NULL, NULL));
+				NULL, 0, 0, 0, NULL, NULL, (guint) -1));
 
 		e_webdav_discover_split_resources (wdd, resources);
 
@@ -760,6 +758,22 @@ e_webdav_discover_sources_sync (ESource *source,
 		out_certificate_pem, out_certificate_errors, out_discovered_sources, out_calendar_user_addresses, cancellable, error);
 }
 
+static gint
+e_webdav_discover_cmp_sources (gconstpointer ptr1,
+			       gconstpointer ptr2)
+{
+	const EWebDAVDiscoveredSource *source1 = ptr1;
+	const EWebDAVDiscoveredSource *source2 = ptr2;
+
+	if (!source1 || !source2)
+		return (source1 ? 1 : 0) - (source2 ? 1 : 0);
+
+	if (source1->order != source2->order && source1->order != (guint) -1 && source2->order != (guint) -1)
+		return source1->order < source2->order ? -1 : 1;
+
+	return g_strcmp0 (source1->display_name, source2->display_name);
+}
+
 /**
  * e_webdav_discover_sources_full_sync:
  * @source: an #ESource from which to take connection details
@@ -1017,7 +1031,7 @@ e_webdav_discover_sources_full_sync (ESource *source,
 			*out_calendar_user_addresses = g_slist_reverse (*out_calendar_user_addresses);
 
 		if (out_discovered_sources && *out_discovered_sources)
-			*out_discovered_sources = g_slist_reverse (*out_discovered_sources);
+			*out_discovered_sources = g_slist_sort (*out_discovered_sources, e_webdav_discover_cmp_sources);
 
 		g_hash_table_destroy (wdd.covered_hrefs);
 	} else {
@@ -1056,6 +1070,7 @@ e_webdav_discovered_source_copy (EWebDAVDiscoveredSource *discovered_source)
 	copy->display_name = g_strdup (discovered_source->display_name);
 	copy->description = g_strdup (discovered_source->description);
 	copy->color = g_strdup (discovered_source->color);
+	copy->order = discovered_source->order;
 
 	return copy;
 }
