@@ -1259,6 +1259,8 @@ e_alarm_notify_new (GCancellable *cancellable,
 	return g_initable_new (
 		E_TYPE_ALARM_NOTIFY, cancellable, error,
 		"application-id", APPLICATION_ID,
+		#if GLIB_CHECK_VERSION(2, 60, 0)
 		"flags", G_APPLICATION_ALLOW_REPLACEMENT,
+		#endif
 		NULL);
 }
