@@ -1861,12 +1861,15 @@ main (gint argc,
 	g_type_init ();
 #endif
 	g_test_init (&argc, &argv, NULL);
+	g_test_bug_base ("https://gitlab.gnome.org/GNOME/evolution-data-server/");
+
+	tcu_read_args (argc, argv);
 
 	/* Ensure that the client and server get the same locale */
 	g_assert (g_setenv ("LC_ALL", "en_US.UTF-8", TRUE));
 	setlocale (LC_ALL, "");
 
-	e_test_server_utils_prepare_run (0);
+	e_test_server_utils_prepare_run (argc, argv, 0);
 	e_test_server_utils_setup (&tsfixture, &tsclosure);
 
 	glob_registry = tsfixture.registry;
